@@ -1,7 +1,8 @@
-from pywizard.resources.file import replace_in_file, file_
+from pywizard.resources.file import file_
 from pywizard.resources.package import package
 from pywizard.resources.service import service
 from pywizard.templating import tpl
+from pywizard_extra_modules.utils import replace_in_file
 
 
 def stunnel(ssl_cert, ssl_key, source, dest):
